@@ -160,8 +160,14 @@ def _get_output_filepath(a, base):
     path = base + '_' + item
     return path
 
-
 def run(ToolImplementation, stdin_data_arg=None, tool_reads_stdin=False):
+    try:
+        return _run(ToolImplementation, stdin_data_arg, tool_reads_stdin)
+    except KeyboardInterrupt:
+        return 1
+    
+
+def _run(ToolImplementation, stdin_data_arg, tool_reads_stdin):
     '''
             tool_reads_stdin - tool uses stdin for other purpose than
                                to obtain startup arguments
